==> pyselfi-1.0.tar.gz: pyselfi-1.0/README.md <==
# pySELFI #

[![arXiv](https://img.shields.io/badge/astro--ph.CO-arxiv%3A1902.10149-B31B1B.svg?style=flat)](https://arxiv.org/abs/1902.10149)
[![GitHub version](https://img.shields.io/github/tag/florent-leclercq/pyselfi.svg?maxAge=3600&label=version)](https://github.com/florent-leclercq/pyselfi)
[![GitHub commits](https://img.shields.io/github/commits-since/florent-leclercq/pyselfi/v1.0.svg)](https://github.com/florent-leclercq/pyselfi/commits)
[![PyPI](https://img.shields.io/pypi/v/pyselfi.svg)](https://pypi.org/project/pyselfi/)
[![DOI](https://zenodo.org/badge/197575311.svg)](https://zenodo.org/badge/latestdoi/197575311)
[![GPLv3 license](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://github.com/florent-leclercq/pyselfi/blob/master/LICENSE)
[![Docs](https://readthedocs.org/projects/pyselfi/badge/)](http://pyselfi.readthedocs.io/en/latest/)
[![Build Status](https://travis-ci.com/florent-leclercq/pyselfi.svg?branch=master)](https://travis-ci.com/florent-leclercq/pyselfi)
[![Website florent-leclercq.eu](https://img.shields.io/website-up-down-green-red/http/pyselfi.florent-leclercq.eu.svg)](http://pyselfi.florent-leclercq.eu/)

Simulator Expansion for Likelihood-Free Inference (SELFI): a python implementation.

## Documentation ##

The code's homepage is [http://pyselfi.florent-leclercq.eu](http://pyselfi.florent-leclercq.eu). The documentation is available on readthedocs at [https://pyselfi.readthedocs.io/](https://pyselfi.readthedocs.io/). Limited user-support may be asked from the main author, Florent Leclercq.

## Contributors ##

* Florent Leclercq, florent.leclercq@polytechnique.org  

## Reference ##

To acknowledge the use of pySELFI in research papers, please cite its Zenodo doi (see the badge above), as well as the paper <a href="https://arxiv.org/abs/1902.10149" target="blank">Leclercq <i>et al.</i> 2019</a>: 

*Primordial power spectrum and cosmology from black-box galaxy surveys*<br/>
F. Leclercq, W. Enzi, J. Jasche, A. Heavens<br/>
<a href="http://arxiv.org/abs/1902.10149" target="blank">arXiv:1902.10149</a> [<a href="http://arxiv.org/abs/1902.10149" target="blank">astro-ph.CO</a>] [<a href="https://ui.adsabs.harvard.edu/?#abs/2019arXiv190210149L" target="blank">ADS</a>] [<a href="http://arxiv.org/pdf/1902.10149" class="document" target="blank">pdf</a>]

    @ARTICLE{pySELFI,
        author = {{Leclercq}, Florent and {Enzi}, Wolfgang and {Jasche}, Jens and {Heavens}, Alan},
        title = "{Primordial power spectrum and cosmology from black-box galaxy surveys}",
        journal = {arXiv e-prints},
        keywords = {Astrophysics - Cosmology and Nongalactic Astrophysics, Astrophysics - Instrumentation and Methods for Astrophysics},
        year = "2019",
        month = "Feb",
        eid = {arXiv:1902.10149},
        pages = {arXiv:1902.10149},
        archivePrefix = {arXiv},
        eprint = {1902.10149},
        primaryClass = {astro-ph.CO},
        adsurl = {https://ui.adsabs.harvard.edu/abs/2019arXiv190210149L},
        adsnote = {Provided by the SAO/NASA Astrophysics Data System}

## License ##

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. By downloading and using pyselfi, you agree to the [LICENSE](LICENSE), distributed with the source code in a text file of the same name.

==> pyselfi-1.2.tar.gz: pyselfi-1.2/README.md <==
# pySELFI #

[![arXiv](https://img.shields.io/badge/astro--ph.CO-arxiv%3A1902.10149-B31B1B.svg?style=flat)](https://arxiv.org/abs/1902.10149)
[![GitHub version](https://img.shields.io/github/tag/florent-leclercq/pyselfi.svg?label=version)](https://github.com/florent-leclercq/pyselfi)
[![GitHub commits](https://img.shields.io/github/commits-since/florent-leclercq/pyselfi/v1.2.svg)](https://github.com/florent-leclercq/pyselfi/commits)
[![DOI](https://zenodo.org/badge/197575311.svg)](https://zenodo.org/badge/latestdoi/197575311)
[![GPLv3 license](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://github.com/florent-leclercq/pyselfi/blob/master/LICENSE)
[![PyPI version](https://badge.fury.io/py/pyselfi.svg)](https://badge.fury.io/py/pyselfi)
[![Docs](https://readthedocs.org/projects/pyselfi/badge/)](http://pyselfi.readthedocs.io/en/latest/)
[![Build Status](https://travis-ci.com/florent-leclercq/pyselfi.svg?branch=master)](https://travis-ci.com/florent-leclercq/pyselfi)
[![Website florent-leclercq.eu](https://img.shields.io/website-up-down-green-red/http/pyselfi.florent-leclercq.eu.svg)](http://pyselfi.florent-leclercq.eu/)

Simulator Expansion for Likelihood-Free Inference (SELFI): a python implementation.

## Documentation ##

The code's homepage is [http://pyselfi.florent-leclercq.eu](http://pyselfi.florent-leclercq.eu). The documentation is available on readthedocs at [https://pyselfi.readthedocs.io/](https://pyselfi.readthedocs.io/). Limited user-support may be asked from the main author, Florent Leclercq.

## Contributors ##

* Florent Leclercq, florent.leclercq@polytechnique.org  

## Reference ##

To acknowledge the use of pySELFI in research papers, please cite its [doi:10.5281/zenodo.3341588](https://doi.org/10.5281/zenodo.3341588) (or for the latest version, see the badge above), as well as the paper <a href="https://arxiv.org/abs/1902.10149" target="blank">Leclercq <i>et al.</i> (2019)</a>: 

*Primordial power spectrum and cosmology from black-box galaxy surveys*<br/>
F. Leclercq, W. Enzi, J. Jasche, A. Heavens<br/>
<a href="http://arxiv.org/abs/1902.10149" target="blank">arXiv:1902.10149</a> [<a href="http://arxiv.org/abs/1902.10149" target="blank">astro-ph.CO</a>] [<a href="https://ui.adsabs.harvard.edu/?#abs/2019arXiv190210149L" target="blank">ADS</a>] [<a href="http://arxiv.org/pdf/1902.10149" class="document" target="blank">pdf</a>]

    @ARTICLE{pySELFI,
        author = {{Leclercq}, Florent and {Enzi}, Wolfgang and {Jasche}, Jens and {Heavens}, Alan},
        title = "{Primordial power spectrum and cosmology from black-box galaxy surveys}",
        journal = {arXiv e-prints},
        keywords = {Astrophysics - Cosmology and Nongalactic Astrophysics, Astrophysics - Instrumentation and Methods for Astrophysics},
        year = "2019",
        month = "Feb",
        eid = {arXiv:1902.10149},
        pages = {arXiv:1902.10149},
        archivePrefix = {arXiv},
        eprint = {1902.10149},
        primaryClass = {astro-ph.CO},
        adsurl = {https://ui.adsabs.harvard.edu/abs/2019arXiv190210149L},
        adsnote = {Provided by the SAO/NASA Astrophysics Data System}
        }

## License ##

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. By downloading and using pySELFI, you agree to the [LICENSE](LICENSE), distributed with the source code in a text file of the same name.
